@@ -472,22 +472,29 @@ class EdgeFactory:
                         if (pi, pj) not in e_dict:
                             continue
 
-                        self._add(
-                            Edge(
-                                source=ci,
-                                target=cj,
-                                kind="design_dependency",
-                                labels=[nodes[pi].annotations.esl_info["type_ref"]],
-                                annotations=dict(
-                                    esl_info=dict(
-                                        reason=e_dict[(pi, pj)].annotations.esl_info[
-                                            "reason"
-                                        ]
-                                    )
-                                ),
-                            ),
-                            "ecd",
-                        )
+                        # Migrate edge up tree
+                        for ai in [ci] + ci.ancestors:
+                            for aj in [cj] + cj.ancestors:
+                                if ai == aj:
+                                    continue
+                                self._add(
+                                    Edge(
+                                        source=ai,
+                                        target=aj,
+                                        kind="design_dependency",
+                                        labels=[
+                                            nodes[pi].annotations.esl_info["type_ref"]
+                                        ],
+                                        annotations=dict(
+                                            esl_info=dict(
+                                                reason=e_dict[
+                                                    (pi, pj)
+                                                ].annotations.esl_info["reason"]
+                                            )
+                                        ),
+                                    ),
+                                    "ecd",
+                                )
 
     def _make_eft(self):
         """Create traceability dependencies between function specifications."""
